==> haskell-tdigest-0.3.1-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tdigest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tdigest
version:              0.3.1
visibility:           public
id:                   tdigest-0.3.1-zlLUjQw5ih1hzPgahAdbl
key:                  tdigest-0.3.1-zlLUjQw5ih1hzPgahAdbl
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/haskell-tdigest#readme
synopsis:             On-line accumulation of rank-based statistics
description:
    A new data structure for accurate on-line accumulation of rank-based statistics such as quantiles and trimmed means.

    See original paper: "Computing extremely accurate quantiles using t-digest" by Ted Dunning and Otmar Ertl
    for more details <https://github.com/tdunning/t-digest/blob/07b8f2ca2be8d0a9f04df2feadad5ddc1bb73c88/docs/t-digest-paper/histo.pdf>.

category:             Numeric
abi:                  44770c3bbbfe75642b81e354aa581ebf
exposed:              True
exposed-modules:
    Data.TDigest Data.TDigest.Internal Data.TDigest.NonEmpty
    Data.TDigest.Postprocess Data.TDigest.Postprocess.Internal
    Data.TDigest.Tree Data.TDigest.Tree.Internal
    Data.TDigest.Tree.NonEmpty Data.TDigest.Tree.Postprocess
    Data.TDigest.Vector Data.TDigest.Vector.Internal
    Data.TDigest.Vector.NonEmpty Data.TDigest.Vector.Postprocess

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tdigest-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tdigest-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tdigest
hs-libraries:         HStdigest-0.3.1-zlLUjQw5ih1hzPgahAdbl
depends:
    base-4.16.4.0 binary-0.8.9.0 deepseq-1.4.6.1
    foldable1-classes-compat-0.1-7NStf6ZT2GxGSdQGw1C5bg
    reducers-3.12.5-HdKju5X8y5D9nAaV4CzZmZ transformers-0.5.6.2
    vector-0.13.1.0-IOJlwkRydAuH1Lkdw56w5r
    vector-algorithms-0.9.1.0-BgUtnQt4AgbGE6KfBQK76o

haddock-interfaces:   /usr/share/doc/haskell-tdigest/html/tdigest.haddock
haddock-html:         /usr/share/doc/haskell-tdigest/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tdigest-0.3.1-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tdigest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tdigest
version:              0.3.1
visibility:           public
id:                   tdigest-0.3.1-7nWQufr5NnxFMDT3jF4q6J
key:                  tdigest-0.3.1-7nWQufr5NnxFMDT3jF4q6J
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/haskell-tdigest#readme
synopsis:             On-line accumulation of rank-based statistics
description:
    A new data structure for accurate on-line accumulation of rank-based statistics such as quantiles and trimmed means.

    See original paper: "Computing extremely accurate quantiles using t-digest" by Ted Dunning and Otmar Ertl
    for more details <https://github.com/tdunning/t-digest/blob/07b8f2ca2be8d0a9f04df2feadad5ddc1bb73c88/docs/t-digest-paper/histo.pdf>.

category:             Numeric
abi:                  6987a69f6702ed2a00e0171ff7fc4800
exposed:              True
exposed-modules:
    Data.TDigest Data.TDigest.Internal Data.TDigest.NonEmpty
    Data.TDigest.Postprocess Data.TDigest.Postprocess.Internal
    Data.TDigest.Tree Data.TDigest.Tree.Internal
    Data.TDigest.Tree.NonEmpty Data.TDigest.Tree.Postprocess
    Data.TDigest.Vector Data.TDigest.Vector.Internal
    Data.TDigest.Vector.NonEmpty Data.TDigest.Vector.Postprocess

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tdigest-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tdigest
hs-libraries:         HStdigest-0.3.1-7nWQufr5NnxFMDT3jF4q6J
depends:
    base-4.17.2.1 binary-0.8.9.1 deepseq-1.4.8.0
    foldable1-classes-compat-0.1-AR3jE1tMs538t9Wr80ZX9s
    reducers-3.12.5-5YAFI4cKRvW3F5YkbUHc1k transformers-0.5.6.2
    vector-0.13.1.0-3m7HMvWbOJNDnUiYgFdHrI
    vector-algorithms-0.9.1.0-H3Rd00y2LlM9FZjiyCfB2r

haddock-interfaces:   /usr/share/doc/haskell-tdigest/html/tdigest.haddock
haddock-html:         /usr/share/doc/haskell-tdigest/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
